CREATE TABLE IF NOT EXISTS `account` (
	`id` integer primary key autoincrement,
	`token` text,
	`last_sync` integer,
	`pro` integer,
    `email` text,
	`currency_default` text,
	`language` text,
	`timezone` int,
	`format_date` text,
	`format_number` text,
    `token_secret` text
);

CREATE TABLE IF NOT EXISTS `expense` (
	`uuid` text primary key,
	`rel_account_id` integer,
	`amount` integer,
    `currency` text,
	`description` text,
	`date` integer,
	`sync` integer,
	`date_modified` integer,
    `deleted` integer
);
	
CREATE TABLE IF NOT EXISTS `expense_to_tag` (
	`id` integer primary key autoincrement,
	`rel_expense_id` text,
	`rel_tag_id` text
);

CREATE TABLE IF NOT EXISTS `tag` (
	`uuid` text primary key,
	`rel_account_id` integer,
	`name` text,
	`count` integer,
	`sync` integer, 
	`date_modified` integer,
    `deleted` integer
); 

CREATE TABLE IF NOT EXISTS `pref_var` (
    `name` text primary key,
    `value` text
);
